@@ -13,6 +13,8 @@ from gajim.common import helpers
 from gajim.common import configpaths
 from gajim.common.connection_handlers_events import MessageNotSentEvent
 
+from gajim.plugins.plugins_i18n import _
+
 from omemo.xmpp import (
     NS_NOTIFY, NS_OMEMO, NS_EME, NS_HINTS, BundleInformationAnnouncement,
     BundleInformationQuery, DeviceListAnnouncement, DevicelistQuery,
@@ -191,6 +193,7 @@ class OMEMOConnection:
 
         event.msgtxt = plaintext
         event.encrypted = self.plugin.encryption_name
+        self.add_additional_data(event.additional_data)
 
     def _mam_message_received(self, event):
         """ Handles an incoming MAM message
@@ -237,6 +240,7 @@ class OMEMOConnection:
 
             event.msgtxt = plaintext
             event.encrypted = self.plugin.encryption_name
+            self.add_additional_data(event.additional_data)
             return
 
     def _message_received(self, msg):
@@ -315,6 +319,7 @@ class OMEMOConnection:
             # gets dropped from history
             msg.stanza.setBody(plaintext)
             msg.encrypted = self.plugin.encryption_name
+            self.add_additional_data(msg.additional_data)
 
     def room_memberlist_received(self, stanza):
         if not nbxmpp.isResultNode(stanza):
@@ -558,6 +563,7 @@ class OMEMOConnection:
         self.print_msg_to_log(event.msg_iq)
         event.xhtml = None
         event.encrypted = self.plugin.encryption_name
+        self.add_additional_data(event.additional_data)
         callback(event)
 
     @staticmethod
@@ -873,6 +879,9 @@ class OMEMOConnection:
         log.debug(stanzastr)
         log.debug('-'*15)
 
+    def add_additional_data(self, data):
+        data['encrypted'] = {'name': self.plugin.encryption_name}
+
 
 class OMEMOError(Exception):
     pass
